@@ -18,6 +18,6 @@ def construct_assignments_for_resource(item) -> AssignmentsForResource:
     return AssignmentsForResource(
         resource_id=item.get("resourceID"),
         assignments=[
-            construct_assignment(assignment) for assignment in item.get("assignments")
+            construct_assignment(assignment) for assignment in item.get("assignments", [])
         ]
     )
