@@ -3,20 +3,20 @@ from dataclasses import dataclass
 
 @dataclass
 class CloudInsightAccount:
-    account_id: str  # A unique identifier for an account
-    name: str  # The account name
-    credentials: dict  # The account credentials to connect to the provider
-    account_type: int  # The type of account
-    tenant_id: str  # The tenantId where the account belongs to
-    created_at: str
-    updated_at: str
-    last_scan_date: str
-    next_scan_date: str
+    id: str = None  # A unique identifier for an account
+    name: str = None  # The account name
+    credentials: dict = None  # The account credentials to connect to the provider
+    account_type: int = None  # The type of account
+    tenant_id: str = None  # The tenantId where the account belongs to
+    created_at: str = None
+    updated_at: str = None
+    last_scan_date: str = None
+    next_scan_date: str = None
 
 
 def construct_cloud_insight_account(item):
     return CloudInsightAccount(
-            account_id=item.get("id"),
+            id=item.get("id"),
             name=item.get("name"),
             credentials=item.get("credentials"),
             account_type=item.get("accountType"),
