@@ -17,6 +17,6 @@ def construct_engine_data(item):
         risk_level=item.get("riskLevel"),
         last_scan_id=item.get("lastScanId"),
         severity_counters=[
-            construct_severity_counter(severity_counter) for severity_counter in item.get("severityCounters")
+            construct_severity_counter(severity_counter) for severity_counter in item.get("severityCounters", [])
         ]
     )
